<?php

return [
    'Names' => [
        'af' => 'Afrikaansk',
        'af_NA' => 'Afrikaansk (Namibië)',
        'af_ZA' => 'Afrikaansk (Sûd-Afrika)',
        'ak' => 'Akan',
        'ak_GH' => 'Akan (Ghana)',
        'am' => 'Amhaarsk',
        'am_ET' => 'Amhaarsk (Ethiopië)',
        'ar' => 'Arabysk',
        'ar_001' => 'Arabysk (Wrâld)',
        'ar_AE' => 'Arabysk (Verenigde Arabyske Emiraten)',
        'ar_BH' => 'Arabysk (Bahrein)',
        'ar_DJ' => 'Arabysk (Djibouti)',
        'ar_DZ' => 'Arabysk (Algerije)',
        'ar_EG' => 'Arabysk (Egypte)',
        'ar_EH' => 'Arabysk (Westelijke Sahara)',
        'ar_ER' => 'Arabysk (Eritrea)',
        'ar_IL' => 'Arabysk (Israël)',
        'ar_IQ' => 'Arabysk (Irak)',
        'ar_JO' => 'Arabysk (Jordanië)',
        'ar_KM' => 'Arabysk (Comoren)',
        'ar_KW' => 'Arabysk (Koeweit)',
        'ar_LB' => 'Arabysk (Libanon)',
        'ar_LY' => 'Arabysk (Libië)',
        'ar_MA' => 'Arabysk (Marokko)',
        'ar_MR' => 'Arabysk (Mauritanië)',
        'ar_OM' => 'Arabysk (Oman)',
        'ar_PS' => 'Arabysk (Palestynske gebieten)',
        'ar_QA' => 'Arabysk (Qatar)',
        'ar_SA' => 'Arabysk (Saoedi-Arabië)',
        'ar_SD' => 'Arabysk (Soedan)',
        'ar_SO' => 'Arabysk (Somalië)',
        'ar_SS' => 'Arabysk (Sûd-Soedan)',
        'ar_SY' => 'Arabysk (Syrië)',
        'ar_TD' => 'Arabysk (Tsjaad)',
        'ar_TN' => 'Arabysk (Tunesië)',
        'ar_YE' => 'Arabysk (Jemen)',
        'as' => 'Assameesk',
        'as_IN' => 'Assameesk (India)',
        'az' => 'Azerbeidzjaansk',
        'az_AZ' => 'Azerbeidzjaansk (Azerbeidzjan)',
        'az_Cyrl' => 'Azerbeidzjaansk (Syrillysk)',
        'az_Cyrl_AZ' => 'Azerbeidzjaansk (Syrillysk, Azerbeidzjan)',
        'az_Latn' => 'Azerbeidzjaansk (Latyn)',
        'az_Latn_AZ' => 'Azerbeidzjaansk (Latyn, Azerbeidzjan)',
        'be' => 'Wyt-Russysk',
        'be_BY' => 'Wyt-Russysk (Wit-Ruslân)',
        'bg' => 'Bulgaarsk',
        'bg_BG' => 'Bulgaarsk (Bulgarije)',
        'bm' => 'Bambara',
        'bm_ML' => 'Bambara (Mali)',
        'bn' => 'Bengaalsk',
        'bn_BD' => 'Bengaalsk (Bangladesh)',
        'bn_IN' => 'Bengaalsk (India)',
        'bo' => 'Tibetaansk',
        'bo_CN' => 'Tibetaansk (Sina)',
        'bo_IN' => 'Tibetaansk (India)',
        'br' => 'Bretonsk',
        'br_FR' => 'Bretonsk (Frankrijk)',
        'bs' => 'Bosnysk',
        'bs_BA' => 'Bosnysk (Bosnië en Herzegovina)',
        'bs_Cyrl' => 'Bosnysk (Syrillysk)',
        'bs_Cyrl_BA' => 'Bosnysk (Syrillysk, Bosnië en Herzegovina)',
        'bs_Latn' => 'Bosnysk (Latyn)',
        'bs_Latn_BA' => 'Bosnysk (Latyn, Bosnië en Herzegovina)',
        'ca' => 'Katalaansk',
        'ca_AD' => 'Katalaansk (Andorra)',
        'ca_ES' => 'Katalaansk (Spanje)',
        'ca_FR' => 'Katalaansk (Frankrijk)',
        'ca_IT' => 'Katalaansk (Italië)',
        'ce' => 'Tsjetsjeensk',
        'ce_RU' => 'Tsjetsjeensk (Ruslân)',
        'cs' => 'Tsjechysk',
        'cs_CZ' => 'Tsjechysk (Tsjechje)',
        'cv' => 'Tsjoevasjysk',
        'cv_RU' => 'Tsjoevasjysk (Ruslân)',
        'cy' => 'Welsk',
        'cy_GB' => 'Welsk (Verenigd Koninkrijk)',
        'da' => 'Deensk',
        'da_DK' => 'Deensk (Denemarken)',
        'da_GL' => 'Deensk (Grienlân)',
        'de' => 'Dútsk',
        'de_AT' => 'Dútsk (Eastenryk)',
        'de_BE' => 'Dútsk (België)',
        'de_CH' => 'Dútsk (Switserlân)',
        'de_DE' => 'Dútsk (Dútslân)',
        'de_IT' => 'Dútsk (Italië)',
        'de_LI' => 'Dútsk (Liechtenstein)',
        'de_LU' => 'Dútsk (Luxemburg)',
        'dz' => 'Dzongkha',
        'dz_BT' => 'Dzongkha (Bhutan)',
        'ee' => 'Ewe',
        'ee_GH' => 'Ewe (Ghana)',
        'ee_TG' => 'Ewe (Togo)',
        'el' => 'Gryks',
        'el_CY' => 'Gryks (Syprus)',
        'el_GR' => 'Gryks (Grikelân)',
        'en' => 'Ingelsk',
        'en_001' => 'Ingelsk (Wrâld)',
        'en_150' => 'Ingelsk (Europa)',
        'en_AE' => 'Ingelsk (Verenigde Arabyske Emiraten)',
        'en_AG' => 'Ingelsk (Antigua en Barbuda)',
        'en_AI' => 'Ingelsk (Anguilla)',
        'en_AS' => 'Ingelsk (Amerikaansk Samoa)',
        'en_AT' => 'Ingelsk (Eastenryk)',
        'en_AU' => 'Ingelsk (Australië)',
        'en_BB' => 'Ingelsk (Barbados)',
        'en_BE' => 'Ingelsk (België)',
        'en_BI' => 'Ingelsk (Burundi)',
        'en_BM' => 'Ingelsk (Bermuda)',
        'en_BS' => 'Ingelsk (Bahama’s)',
        'en_BW' => 'Ingelsk (Botswana)',
        'en_BZ' => 'Ingelsk (Belize)',
        'en_CA' => 'Ingelsk (Canada)',
        'en_CC' => 'Ingelsk (Kokosilanen)',
        'en_CH' => 'Ingelsk (Switserlân)',
        'en_CK' => 'Ingelsk (Cookeilannen)',
        'en_CM' => 'Ingelsk (Kameroen)',
        'en_CX' => 'Ingelsk (Krysteilan)',
        'en_CY' => 'Ingelsk (Syprus)',
        'en_DE' => 'Ingelsk (Dútslân)',
        'en_DK' => 'Ingelsk (Denemarken)',
        'en_DM' => 'Ingelsk (Dominika)',
        'en_ER' => 'Ingelsk (Eritrea)',
        'en_FI' => 'Ingelsk (Finlân)',
        'en_FJ' => 'Ingelsk (Fiji)',
        'en_FK' => 'Ingelsk (Falklâneilannen)',
        'en_FM' => 'Ingelsk (Micronesië)',
        'en_GB' => 'Ingelsk (Verenigd Koninkrijk)',
        'en_GD' => 'Ingelsk (Grenada)',
        'en_GG' => 'Ingelsk (Guernsey)',
        'en_GH' => 'Ingelsk (Ghana)',
        'en_GI' => 'Ingelsk (Gibraltar)',
        'en_GM' => 'Ingelsk (Gambia)',
        'en_GU' => 'Ingelsk (Guam)',
        'en_GY' => 'Ingelsk (Guyana)',
        'en_HK' => 'Ingelsk (Hongkong SAR van Sina)',
        'en_IE' => 'Ingelsk (Ierlân)',
        'en_IL' => 'Ingelsk (Israël)',
        'en_IM' => 'Ingelsk (Isle of Man)',
        'en_IN' => 'Ingelsk (India)',
        'en_IO' => 'Ingelsk (Britse Gebieden yn de Indyske Oseaan)',
        'en_JE' => 'Ingelsk (Jersey)',
        'en_JM' => 'Ingelsk (Jamaica)',
        'en_KE' => 'Ingelsk (Kenia)',
        'en_KI' => 'Ingelsk (Kiribati)',
        'en_KN' => 'Ingelsk (Saint Kitts en Nevis)',
        'en_KY' => 'Ingelsk (Caymaneilannen)',
        'en_LC' => 'Ingelsk (Saint Lucia)',
        'en_LR' => 'Ingelsk (Liberia)',
        'en_LS' => 'Ingelsk (Lesotho)',
        'en_MG' => 'Ingelsk (Madeiaskar)',
        'en_MH' => 'Ingelsk (Marshalleilannen)',
        'en_MO' => 'Ingelsk (Macao SAR van Sina)',
        'en_MP' => 'Ingelsk (Noardlike Marianeneilannen)',
        'en_MS' => 'Ingelsk (Montserrat)',
        'en_MT' => 'Ingelsk (Malta)',
        'en_MU' => 'Ingelsk (Mauritius)',
        'en_MV' => 'Ingelsk (Maldiven)',
        'en_MW' => 'Ingelsk (Malawi)',
        'en_MY' => 'Ingelsk (Maleisië)',
        'en_NA' => 'Ingelsk (Namibië)',
        'en_NF' => 'Ingelsk (Norfolkeilân)',
        'en_NG' => 'Ingelsk (Nigeria)',
        'en_NL' => 'Ingelsk (Nederlân)',
        'en_NR' => 'Ingelsk (Nauru)',
        'en_NU' => 'Ingelsk (Niue)',
        'en_NZ' => 'Ingelsk (Nij-Seelân)',
        'en_PG' => 'Ingelsk (Papoea-Nij-Guinea)',
        'en_PH' => 'Ingelsk (Filipijnen)',
        'en_PK' => 'Ingelsk (Pakistan)',
        'en_PN' => 'Ingelsk (Pitcairneilannen)',
        'en_PR' => 'Ingelsk (Puerto Rico)',
        'en_PW' => 'Ingelsk (Palau)',
        'en_RW' => 'Ingelsk (Rwanda)',
        'en_SB' => 'Ingelsk (Salomonseilannen)',
        'en_SC' => 'Ingelsk (Seychellen)',
        'en_SD' => 'Ingelsk (Soedan)',
        'en_SE' => 'Ingelsk (Zweden)',
        'en_SG' => 'Ingelsk (Singapore)',
        'en_SH' => 'Ingelsk (Sint-Helena)',
        'en_SI' => 'Ingelsk (Slovenië)',
        'en_SL' => 'Ingelsk (Sierra Leone)',
        'en_SS' => 'Ingelsk (Sûd-Soedan)',
        'en_SX' => 'Ingelsk (Sint-Maarten)',
        'en_SZ' => 'Ingelsk (Swazilân)',
        'en_TC' => 'Ingelsk (Turks- en Caicoseilannen)',
        'en_TK' => 'Ingelsk (Tokelau)',
        'en_TO' => 'Ingelsk (Tonga)',
        'en_TT' => 'Ingelsk (Trinidad en Tobago)',
        'en_TV' => 'Ingelsk (Tuvalu)',
        'en_TZ' => 'Ingelsk (Tanzania)',
        'en_UG' => 'Ingelsk (Oeganda)',
        'en_UM' => 'Ingelsk (Lyts ôflizzen eilannen fan de Ferienigde Staten)',
        'en_US' => 'Ingelsk (Ferienigde Staten)',
        'en_VC' => 'Ingelsk (Saint Vincent en de Grenadines)',
        'en_VG' => 'Ingelsk (Britse Maagdeneilannen)',
        'en_VI' => 'Ingelsk (Amerikaanske Maagdeneilannen)',
        'en_VU' => 'Ingelsk (Vanuatu)',
        'en_WS' => 'Ingelsk (Samoa)',
        'en_ZA' => 'Ingelsk (Sûd-Afrika)',
        'en_ZM' => 'Ingelsk (Zambia)',
        'en_ZW' => 'Ingelsk (Zimbabwe)',
        'eo' => 'Esperanto',
        'eo_001' => 'Esperanto (Wrâld)',
        'es' => 'Spaansk',
        'es_419' => 'Spaansk (Latynsk-Amearika)',
        'es_AR' => 'Spaansk (Argentinië)',
        'es_BO' => 'Spaansk (Bolivia)',
        'es_BR' => 'Spaansk (Brazilië)',
        'es_BZ' => 'Spaansk (Belize)',
        'es_CL' => 'Spaansk (Chili)',
        'es_CO' => 'Spaansk (Kolombia)',
        'es_CR' => 'Spaansk (Costa Rica)',
        'es_CU' => 'Spaansk (Kuba)',
        'es_DO' => 'Spaansk (Dominikaanske Republyk)',
        'es_EC' => 'Spaansk (Ecuador)',
        'es_ES' => 'Spaansk (Spanje)',
        'es_GQ' => 'Spaansk (Equatoriaal-Guinea)',
        'es_GT' => 'Spaansk (Guatemala)',
        'es_HN' => 'Spaansk (Honduras)',
        'es_MX' => 'Spaansk (Mexico)',
        'es_NI' => 'Spaansk (Nicaragua)',
        'es_PA' => 'Spaansk (Panama)',
        'es_PE' => 'Spaansk (Peru)',
        'es_PH' => 'Spaansk (Filipijnen)',
        'es_PR' => 'Spaansk (Puerto Rico)',
        'es_PY' => 'Spaansk (Paraguay)',
        'es_SV' => 'Spaansk (El Salvador)',
        'es_US' => 'Spaansk (Ferienigde Staten)',
        'es_UY' => 'Spaansk (Uruguay)',
        'es_VE' => 'Spaansk (Venezuela)',
        'et' => 'Estlânsk',
        'et_EE' => 'Estlânsk (Estlân)',
        'eu' => 'Baskysk',
        'eu_ES' => 'Baskysk (Spanje)',
        'fa' => 'Perzysk',
        'fa_AF' => 'Perzysk (Afghanistan)',
        'fa_IR' => 'Perzysk (Iran)',
        'ff' => 'Fulah',
        'ff_CM' => 'Fulah (Kameroen)',
        'ff_GN' => 'Fulah (Guinee)',
        'ff_Latn' => 'Fulah (Latyn)',
        'ff_Latn_BF' => 'Fulah (Latyn, Burkina Faso)',
        'ff_Latn_CM' => 'Fulah (Latyn, Kameroen)',
        'ff_Latn_GH' => 'Fulah (Latyn, Ghana)',
        'ff_Latn_GM' => 'Fulah (Latyn, Gambia)',
        'ff_Latn_GN' => 'Fulah (Latyn, Guinee)',
        'ff_Latn_GW' => 'Fulah (Latyn, Guinee-Bissau)',
        'ff_Latn_LR' => 'Fulah (Latyn, Liberia)',
        'ff_Latn_MR' => 'Fulah (Latyn, Mauritanië)',
        'ff_Latn_NE' => 'Fulah (Latyn, Niger)',
        'ff_Latn_NG' => 'Fulah (Latyn, Nigeria)',
        'ff_Latn_SL' => 'Fulah (Latyn, Sierra Leone)',
        'ff_Latn_SN' => 'Fulah (Latyn, Senegal)',
        'ff_MR' => 'Fulah (Mauritanië)',
        'ff_SN' => 'Fulah (Senegal)',
        'fi' => 'Finsk',
        'fi_FI' => 'Finsk (Finlân)',
        'fo' => 'Faeröersk',
        'fo_DK' => 'Faeröersk (Denemarken)',
        'fo_FO' => 'Faeröersk (Faeröer)',
        'fr' => 'Frânsk',
        'fr_BE' => 'Frânsk (België)',
        'fr_BF' => 'Frânsk (Burkina Faso)',
        'fr_BI' => 'Frânsk (Burundi)',
        'fr_BJ' => 'Frânsk (Benin)',
        'fr_BL' => 'Frânsk (Saint Barthélemy)',
        'fr_CA' => 'Frânsk (Canada)',
        'fr_CD' => 'Frânsk (Congo-Kinshasa)',
        'fr_CF' => 'Frânsk (Sintraal-Afrikaanske Republyk)',
        'fr_CG' => 'Frânsk (Congo-Brazzaville)',
        'fr_CH' => 'Frânsk (Switserlân)',
        'fr_CI' => 'Frânsk (Ivoorkust)',
        'fr_CM' => 'Frânsk (Kameroen)',
        'fr_DJ' => 'Frânsk (Djibouti)',
        'fr_DZ' => 'Frânsk (Algerije)',
        'fr_FR' => 'Frânsk (Frankrijk)',
        'fr_GA' => 'Frânsk (Gabon)',
        'fr_GF' => 'Frânsk (Frans-Guyana)',
        'fr_GN' => 'Frânsk (Guinee)',
        'fr_GP' => 'Frânsk (Guadeloupe)',
        'fr_GQ' => 'Frânsk (Equatoriaal-Guinea)',
        'fr_HT' => 'Frânsk (Haïti)',
        'fr_KM' => 'Frânsk (Comoren)',
        'fr_LU' => 'Frânsk (Luxemburg)',
        'fr_MA' => 'Frânsk (Marokko)',
        'fr_MC' => 'Frânsk (Monaco)',
        'fr_MF' => 'Frânsk (Saint-Martin)',
        'fr_MG' => 'Frânsk (Madeiaskar)',
        'fr_ML' => 'Frânsk (Mali)',
        'fr_MQ' => 'Frânsk (Martinique)',
        'fr_MR' => 'Frânsk (Mauritanië)',
        'fr_MU' => 'Frânsk (Mauritius)',
        'fr_NC' => 'Frânsk (Nij-Caledonië)',
        'fr_NE' => 'Frânsk (Niger)',
        'fr_PF' => 'Frânsk (Frans-Polynesië)',
        'fr_PM' => 'Frânsk (Saint-Pierre en Miquelon)',
        'fr_RE' => 'Frânsk (Réunion)',
        'fr_RW' => 'Frânsk (Rwanda)',
        'fr_SC' => 'Frânsk (Seychellen)',
        'fr_SN' => 'Frânsk (Senegal)',
        'fr_SY' => 'Frânsk (Syrië)',
        'fr_TD' => 'Frânsk (Tsjaad)',
        'fr_TG' => 'Frânsk (Togo)',
        'fr_TN' => 'Frânsk (Tunesië)',
        'fr_VU' => 'Frânsk (Vanuatu)',
        'fr_WF' => 'Frânsk (Wallis en Futuna)',
        'fr_YT' => 'Frânsk (Mayotte)',
        'fy' => 'Frysk',
        'fy_NL' => 'Frysk (Nederlân)',
        'ga' => 'Iersk',
        'ga_GB' => 'Iersk (Verenigd Koninkrijk)',
        'ga_IE' => 'Iersk (Ierlân)',
        'gd' => 'Schotsk Gaelic',
        'gd_GB' => 'Schotsk Gaelic (Verenigd Koninkrijk)',
        'gl' => 'Galisysk',
        'gl_ES' => 'Galisysk (Spanje)',
        'gu' => 'Gujarati',
        'gu_IN' => 'Gujarati (India)',
        'gv' => 'Manks',
        'gv_IM' => 'Manks (Isle of Man)',
        'ha' => 'Hausa',
        'ha_GH' => 'Hausa (Ghana)',
        'ha_NE' => 'Hausa (Niger)',
        'ha_NG' => 'Hausa (Nigeria)',
        'he' => 'Hebreeuwsk',
        'he_IL' => 'Hebreeuwsk (Israël)',
        'hi' => 'Hindi',
        'hi_IN' => 'Hindi (India)',
        'hi_Latn' => 'Hindi (Latyn)',
        'hi_Latn_IN' => 'Hindi (Latyn, India)',
        'hr' => 'Kroatysk',
        'hr_BA' => 'Kroatysk (Bosnië en Herzegovina)',
        'hr_HR' => 'Kroatysk (Kroatië)',
        'hu' => 'Hongaarsk',
        'hu_HU' => 'Hongaarsk (Hongarije)',
        'hy' => 'Armeensk',
        'hy_AM' => 'Armeensk (Armenië)',
        'ia' => 'Interlingua',
        'ia_001' => 'Interlingua (Wrâld)',
        'id' => 'Yndonezysk',
        'id_ID' => 'Yndonezysk (Yndonesië)',
        'ig' => 'Igbo',
        'ig_NG' => 'Igbo (Nigeria)',
        'ii' => 'Sichuan Yi',
        'ii_CN' => 'Sichuan Yi (Sina)',
        'is' => 'Yslâns',
        'is_IS' => 'Yslâns (Yslân)',
        'it' => 'Italiaansk',
        'it_CH' => 'Italiaansk (Switserlân)',
        'it_IT' => 'Italiaansk (Italië)',
        'it_SM' => 'Italiaansk (San Marino)',
        'it_VA' => 'Italiaansk (Vaticaanstêd)',
        'ja' => 'Japans',
        'ja_JP' => 'Japans (Japan)',
        'jv' => 'Javaansk',
        'jv_ID' => 'Javaansk (Yndonesië)',
        'ka' => 'Georgysk',
        'ka_GE' => 'Georgysk (Georgië)',
        'ki' => 'Kikuyu',
        'ki_KE' => 'Kikuyu (Kenia)',
        'kk' => 'Kazachs',
        'kk_KZ' => 'Kazachs (Kazachstan)',
        'kl' => 'Grienlâns',
        'kl_GL' => 'Grienlâns (Grienlân)',
        'km' => 'Khmer',
        'km_KH' => 'Khmer (Cambodja)',
        'kn' => 'Kannada',
        'kn_IN' => 'Kannada (India)',
        'ko' => 'Koreaansk',
        'ko_KP' => 'Koreaansk (Noard-Korea)',
        'ko_KR' => 'Koreaansk (Sûd-Korea)',
        'ks' => 'Kasjmiri',
        'ks_Arab' => 'Kasjmiri (Arabysk)',
        'ks_Arab_IN' => 'Kasjmiri (Arabysk, India)',
        'ks_Deva' => 'Kasjmiri (Devanagari)',
        'ks_Deva_IN' => 'Kasjmiri (Devanagari, India)',
        'ks_IN' => 'Kasjmiri (India)',
        'ku' => 'Koerdysk',
        'ku_TR' => 'Koerdysk (Turkije)',
        'kw' => 'Cornish',
        'kw_GB' => 'Cornish (Verenigd Koninkrijk)',
        'ky' => 'Kirgizysk',
        'ky_KG' => 'Kirgizysk (Kirgizië)',
        'lb' => 'Luxemburgs',
        'lb_LU' => 'Luxemburgs (Luxemburg)',
        'lg' => 'Ganda',
        'lg_UG' => 'Ganda (Oeganda)',
        'ln' => 'Lingala',
        'ln_AO' => 'Lingala (Angola)',
        'ln_CD' => 'Lingala (Congo-Kinshasa)',
        'ln_CF' => 'Lingala (Sintraal-Afrikaanske Republyk)',
        'ln_CG' => 'Lingala (Congo-Brazzaville)',
        'lo' => 'Laotiaansk',
        'lo_LA' => 'Laotiaansk (Laos)',
        'lt' => 'Litouws',
        'lt_LT' => 'Litouws (Litouwen)',
        'lu' => 'Luba-Katanga',
        'lu_CD' => 'Luba-Katanga (Congo-Kinshasa)',
        'lv' => 'Letlâns',
        'lv_LV' => 'Letlâns (Letlân)',
        'mg' => 'Malagasysk',
        'mg_MG' => 'Malagasysk (Madeiaskar)',
        'mi' => 'Maori',
        'mi_NZ' => 'Maori (Nij-Seelân)',
        'mk' => 'Macedonysk',
        'ml' => 'Malayalam',
        'ml_IN' => 'Malayalam (India)',
        'mn' => 'Mongools',
        'mn_MN' => 'Mongools (Mongolië)',
        'mr' => 'Marathi',
        'mr_IN' => 'Marathi (India)',
        'ms' => 'Maleis',
        'ms_BN' => 'Maleis (Brunei)',
        'ms_ID' => 'Maleis (Yndonesië)',
        'ms_MY' => 'Maleis (Maleisië)',
        'ms_SG' => 'Maleis (Singapore)',
        'mt' => 'Maltees',
        'mt_MT' => 'Maltees (Malta)',
        'my' => 'Birmees',
        'my_MM' => 'Birmees (Myanmar [Birma])',
        'nb' => 'Noors - Bokmål',
        'nb_NO' => 'Noors - Bokmål (Noarwegen)',
        'nb_SJ' => 'Noors - Bokmål (Spitsbergen en Jan Mayen)',
        'nd' => 'Noard-Ndbele',
        'nd_ZW' => 'Noard-Ndbele (Zimbabwe)',
        'ne' => 'Nepalees',
        'ne_IN' => 'Nepalees (India)',
        'ne_NP' => 'Nepalees (Nepal)',
        'nl' => 'Nederlânsk',
        'nl_AW' => 'Nederlânsk (Aruba)',
        'nl_BE' => 'Nederlânsk (België)',
        'nl_BQ' => 'Nederlânsk (Karibysk Nederlân)',
        'nl_CW' => 'Nederlânsk (Curaçao)',
        'nl_NL' => 'Nederlânsk (Nederlân)',
        'nl_SR' => 'Nederlânsk (Suriname)',
        'nl_SX' => 'Nederlânsk (Sint-Maarten)',
        'nn' => 'Noors - Nynorsk',
        'nn_NO' => 'Noors - Nynorsk (Noarwegen)',
        'no' => 'Noors',
        'no_NO' => 'Noors (Noarwegen)',
        'om' => 'Oromo',
        'om_ET' => 'Oromo (Ethiopië)',
        'om_KE' => 'Oromo (Kenia)',
        'or' => 'Odia',
        'or_IN' => 'Odia (India)',
        'os' => 'Ossetysk',
        'os_GE' => 'Ossetysk (Georgië)',
        'os_RU' => 'Ossetysk (Ruslân)',
        'pa' => 'Punjabi',
        'pa_Arab' => 'Punjabi (Arabysk)',
        'pa_Arab_PK' => 'Punjabi (Arabysk, Pakistan)',
        'pa_Guru' => 'Punjabi (Gurmukhi)',
        'pa_Guru_IN' => 'Punjabi (Gurmukhi, India)',
        'pa_IN' => 'Punjabi (India)',
        'pa_PK' => 'Punjabi (Pakistan)',
        'pl' => 'Poalsk',
        'pl_PL' => 'Poalsk (Polen)',
        'ps' => 'Pasjtoe',
        'ps_AF' => 'Pasjtoe (Afghanistan)',
        'ps_PK' => 'Pasjtoe (Pakistan)',
        'pt' => 'Portugeesk',
        'pt_AO' => 'Portugeesk (Angola)',
        'pt_BR' => 'Portugeesk (Brazilië)',
        'pt_CH' => 'Portugeesk (Switserlân)',
        'pt_CV' => 'Portugeesk (Kaapverdië)',
        'pt_GQ' => 'Portugeesk (Equatoriaal-Guinea)',
        'pt_GW' => 'Portugeesk (Guinee-Bissau)',
        'pt_LU' => 'Portugeesk (Luxemburg)',
        'pt_MO' => 'Portugeesk (Macao SAR van Sina)',
        'pt_MZ' => 'Portugeesk (Mozambique)',
        'pt_PT' => 'Portugeesk (Portugal)',
        'pt_ST' => 'Portugeesk (Sao Tomé en Principe)',
        'pt_TL' => 'Portugeesk (East-Timor)',
        'qu' => 'Quechua',
        'qu_BO' => 'Quechua (Bolivia)',
        'qu_EC' => 'Quechua (Ecuador)',
        'qu_PE' => 'Quechua (Peru)',
        'rm' => 'Reto-Romaansk',
        'rm_CH' => 'Reto-Romaansk (Switserlân)',
        'rn' => 'Kirundi',
        'rn_BI' => 'Kirundi (Burundi)',
        'ro' => 'Roemeensk',
        'ro_MD' => 'Roemeensk (Moldavië)',
        'ro_RO' => 'Roemeensk (Roemenië)',
        'ru' => 'Russysk',
        'ru_BY' => 'Russysk (Wit-Ruslân)',
        'ru_KG' => 'Russysk (Kirgizië)',
        'ru_KZ' => 'Russysk (Kazachstan)',
        'ru_MD' => 'Russysk (Moldavië)',
        'ru_RU' => 'Russysk (Ruslân)',
        'ru_UA' => 'Russysk (Oekraïne)',
        'rw' => 'Kinyarwanda',
        'rw_RW' => 'Kinyarwanda (Rwanda)',
        'sa' => 'Sanskriet',
        'sa_IN' => 'Sanskriet (India)',
        'sc' => 'Sardinysk',
        'sc_IT' => 'Sardinysk (Italië)',
        'sd' => 'Sindhi',
        'sd_Arab' => 'Sindhi (Arabysk)',
        'sd_Arab_PK' => 'Sindhi (Arabysk, Pakistan)',
        'sd_Deva' => 'Sindhi (Devanagari)',
        'sd_Deva_IN' => 'Sindhi (Devanagari, India)',
        'sd_IN' => 'Sindhi (India)',
        'sd_PK' => 'Sindhi (Pakistan)',
        'se' => 'Noard-Samysk',
        'se_FI' => 'Noard-Samysk (Finlân)',
        'se_NO' => 'Noard-Samysk (Noarwegen)',
        'se_SE' => 'Noard-Samysk (Zweden)',
        'sg' => 'Sango',
        'sg_CF' => 'Sango (Sintraal-Afrikaanske Republyk)',
        'sh' => 'Servokroatysk',
        'sh_BA' => 'Servokroatysk (Bosnië en Herzegovina)',
        'si' => 'Singalees',
        'si_LK' => 'Singalees (Sri Lanka)',
        'sk' => 'Slowaaks',
        'sk_SK' => 'Slowaaks (Slowakije)',
        'sl' => 'Sloveensk',
        'sl_SI' => 'Sloveensk (Slovenië)',
        'sn' => 'Shona',
        'sn_ZW' => 'Shona (Zimbabwe)',
        'so' => 'Somalysk',
        'so_DJ' => 'Somalysk (Djibouti)',
        'so_ET' => 'Somalysk (Ethiopië)',
        'so_KE' => 'Somalysk (Kenia)',
        'so_SO' => 'Somalysk (Somalië)',
        'sq' => 'Albaneesk',
        'sq_AL' => 'Albaneesk (Albanië)',
        'sr' => 'Servysk',
        'sr_BA' => 'Servysk (Bosnië en Herzegovina)',
        'sr_Cyrl' => 'Servysk (Syrillysk)',
        'sr_Cyrl_BA' => 'Servysk (Syrillysk, Bosnië en Herzegovina)',
        'sr_Cyrl_ME' => 'Servysk (Syrillysk, Montenegro)',
        'sr_Cyrl_RS' => 'Servysk (Syrillysk, Servië)',
        'sr_Latn' => 'Servysk (Latyn)',
        'sr_Latn_BA' => 'Servysk (Latyn, Bosnië en Herzegovina)',
        'sr_Latn_ME' => 'Servysk (Latyn, Montenegro)',
        'sr_Latn_RS' => 'Servysk (Latyn, Servië)',
        'sr_ME' => 'Servysk (Montenegro)',
        'sr_RS' => 'Servysk (Servië)',
        'su' => 'Soendaneesk',
        'su_ID' => 'Soendaneesk (Yndonesië)',
        'su_Latn' => 'Soendaneesk (Latyn)',
        'su_Latn_ID' => 'Soendaneesk (Latyn, Yndonesië)',
        'sv' => 'Zweeds',
        'sv_AX' => 'Zweeds (Ålân)',
        'sv_FI' => 'Zweeds (Finlân)',
        'sv_SE' => 'Zweeds (Zweden)',
        'sw' => 'Swahili',
        'sw_CD' => 'Swahili (Congo-Kinshasa)',
        'sw_KE' => 'Swahili (Kenia)',
        'sw_TZ' => 'Swahili (Tanzania)',
        'sw_UG' => 'Swahili (Oeganda)',
        'ta' => 'Tamil',
        'ta_IN' => 'Tamil (India)',
        'ta_LK' => 'Tamil (Sri Lanka)',
        'ta_MY' => 'Tamil (Maleisië)',
        'ta_SG' => 'Tamil (Singapore)',
        'te' => 'Telugu',
        'te_IN' => 'Telugu (India)',
        'tg' => 'Tadzjieks',
        'tg_TJ' => 'Tadzjieks (Tadzjikistan)',
        'th' => 'Thais',
        'th_TH' => 'Thais (Thailân)',
        'ti' => 'Tigrinya',
        'ti_ER' => 'Tigrinya (Eritrea)',
        'ti_ET' => 'Tigrinya (Ethiopië)',
        'tk' => 'Turkmeens',
        'tk_TM' => 'Turkmeens (Turkmenistan)',
        'tl' => 'Tagalog',
        'tl_PH' => 'Tagalog (Filipijnen)',
        'to' => 'Tongaansk',
        'to_TO' => 'Tongaansk (Tonga)',
        'tr' => 'Turks',
        'tr_CY' => 'Turks (Syprus)',
        'tr_TR' => 'Turks (Turkije)',
        'tt' => 'Tataars',
        'tt_RU' => 'Tataars (Ruslân)',
        'ug' => 'Oeigoers',
        'ug_CN' => 'Oeigoers (Sina)',
        'uk' => 'Oekraïens',
        'uk_UA' => 'Oekraïens (Oekraïne)',
        'ur' => 'Urdu',
        'ur_IN' => 'Urdu (India)',
        'ur_PK' => 'Urdu (Pakistan)',
        'uz' => 'Oezbeeks',
        'uz_AF' => 'Oezbeeks (Afghanistan)',
        'uz_Arab' => 'Oezbeeks (Arabysk)',
        'uz_Arab_AF' => 'Oezbeeks (Arabysk, Afghanistan)',
        'uz_Cyrl' => 'Oezbeeks (Syrillysk)',
        'uz_Cyrl_UZ' => 'Oezbeeks (Syrillysk, Oezbekistan)',
        'uz_Latn' => 'Oezbeeks (Latyn)',
        'uz_Latn_UZ' => 'Oezbeeks (Latyn, Oezbekistan)',
        'uz_UZ' => 'Oezbeeks (Oezbekistan)',
        'vi' => 'Vietnamees',
        'vi_VN' => 'Vietnamees (Vietnam)',
        'wo' => 'Wolof',
        'wo_SN' => 'Wolof (Senegal)',
        'xh' => 'Xhosa',
        'xh_ZA' => 'Xhosa (Sûd-Afrika)',
        'yi' => 'Jiddysk',
        'yi_001' => 'Jiddysk (Wrâld)',
        'yo' => 'Yoruba',
        'yo_BJ' => 'Yoruba (Benin)',
        'yo_NG' => 'Yoruba (Nigeria)',
        'zh' => 'Sineesk',
        'zh_CN' => 'Sineesk (Sina)',
        'zh_HK' => 'Sineesk (Hongkong SAR van Sina)',
        'zh_Hans' => 'Sineesk (Ferienfâldigd)',
        'zh_Hans_CN' => 'Sineesk (Ferienfâldigd, Sina)',
        'zh_Hans_HK' => 'Sineesk (Ferienfâldigd, Hongkong SAR van Sina)',
        'zh_Hans_MO' => 'Sineesk (Ferienfâldigd, Macao SAR van Sina)',
        'zh_Hans_SG' => 'Sineesk (Ferienfâldigd, Singapore)',
        'zh_Hant' => 'Sineesk (Traditjoneel)',
        'zh_Hant_HK' => 'Sineesk (Traditjoneel, Hongkong SAR van Sina)',
        'zh_Hant_MO' => 'Sineesk (Traditjoneel, Macao SAR van Sina)',
        'zh_Hant_TW' => 'Sineesk (Traditjoneel, Taiwan)',
        'zh_MO' => 'Sineesk (Macao SAR van Sina)',
        'zh_SG' => 'Sineesk (Singapore)',
        'zh_TW' => 'Sineesk (Taiwan)',
        'zu' => 'Zulu',
        'zu_ZA' => 'Zulu (Sûd-Afrika)',
    ],
];
